@@ -33,11 +33,12 @@
 
 // EMail from session (s.a. pre_ctrl)
 $filename    = $App->getParam('name');
+$attachmentId = $App->getParam('attachmentId');
 $contentType = $App->getParam('type');
 $sessionMailId = $App->getParam('id');
 
 try {
-    $attachmentData = $Backend->fetchAttachment($archive,$sessionMailId,$filename);
+    $attachmentData = $Backend->fetchAttachment($archive,$sessionMailId,$filename, $attachmentId);
 
     header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
     header("Pragma: public");
@@ -53,4 +54,4 @@ catch (Exception $e) {
     $App->view = 'error';
 }
 
-?>
+?>
\ No newline at end of file
