@@ -50,7 +50,7 @@ class Backend
         global $App;
         $this->rest_user = $rest_user;
         $this->rest_pass = $rest_pass;
-        $this->rest_ssl_verify = $App->getConfig('REST_SSL_VERIFY');
+        $this->rest_ssl_verify = $App->getConfig('REST_SSL_VERIFY','NO');
 
         $this->base_url = $base_url;
         $this->filter = $filter;
@@ -228,7 +228,7 @@ class Backend
         $resultList = $this->_curl_query($request_url,$query);
 
         if (! preg_match('/^LICENSE_VALID/',$resultList['licenseValid'])) {
-            if ($App->getConfig('USERPERMISSONS') != 'DISABLED') {
+            if ($App->getConfig('USERPERMISSONS','ENABLED') != 'DISABLED') {
                 $App->setMsg('LICENSE_ERROR');
                 throw new Exception('LICENSE_ERROR');
             }
