@@ -48,6 +48,7 @@ class Query
     var $headerValue;       // will only be set on extended search
     var $isAttachment;
     var $isSpam;
+    var $spamQuery;
     var $dateFrom;          // 01.01.1970
     var $dateTo;            // 31.12.2011
     var $type;              // Type of this query: Simple, Ext, Konv
@@ -65,6 +66,8 @@ class Query
      */
     function Query ($id,$archive='',$text='',$dateFrom='',$dateTo='',$sender='',$recipient='',$subject='',$headerName='',$headerValue='',$isAttachment=false,$isSpam=false,$type='Simple')
     {
+        global $App;
+
         $this->id = $id;
         $this->archive = $archive;
         $this->text = $text;          // content or search term
@@ -79,6 +82,8 @@ class Query
         $this->isSpam = $isSpam;
         $this->sort  = array('field' => 'Date', 'ascending' => 'false');
         $this->type = $type;
+
+        $this->spamQuery = $App->getConfig('SPAM_QUERY','AND NOT HEADER-X-SPAM-FLAG:YES');
     }
 
 
@@ -214,6 +219,16 @@ class Query
     }
 
 
+    /**
+     * SPAM filter query
+     *
+     */  
+    function setSpamQuery($query)
+    {
+        $this->spamQuery = $query;
+    }
+
+
     /**
      * Set the sort field and order
      *
@@ -246,7 +261,7 @@ class Query
         $query_string = '('.$this->_format_query($qstring,$fieldlist).')';
 
         if (! $this->isSpam) {
-            $query_string .= ' AND NOT HEADER-X-SPAM-FLAG:YES';
+            $query_string .= ' '.$this->spamQuery;
         }
 
         $date_range   = $this->_dateRange($this->dateFrom,$this->dateTo);
@@ -336,8 +351,7 @@ class Query
         }
 
         if (!$this->isSpam) {
-            // Todo customizable spam flag headers
-            $query_string .= 'NOT HEADER-X-SPAM-FLAG:YES'.$and;
+            $query_string .= $this->spamQuery.$and;
         }
 
         $date_range   = $this->_dateRange($this->dateFrom,$this->dateTo);
